@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class DeleteEngineNamespaceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'DeleteEngineNamespace')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'DeleteEngineNamespace','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -41,6 +41,11 @@ class DeleteEngineNamespaceRequest(RpcRequest):
 
 	def set_InstanceId(self, InstanceId):  # String
 		self.add_query_param('InstanceId', InstanceId)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
 	def get_Id(self): # String
 		return self.get_query_params().get('Id')
 
