@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class ExportNacosConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ExportNacosConfig')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ExportNacosConfig','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -51,6 +51,11 @@ class ExportNacosConfigRequest(RpcRequest):
 
 	def set_NamespaceId(self, NamespaceId):  # String
 		self.add_query_param('NamespaceId', NamespaceId)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
 	def get_Ids(self): # String
 		return self.get_query_params().get('Ids')
 
