@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class ListAlarmItemsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListAlarmItems')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListAlarmItems','mse')
 		self.set_method('GET')
 
 		if hasattr(self, "endpoint_map"):
@@ -36,3 +36,8 @@ class ListAlarmItemsRequest(RpcRequest):
 
 	def set_RequestPars(self, RequestPars):  # String
 		self.add_query_param('RequestPars', RequestPars)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
