@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class ListAlarmRulesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListAlarmRules')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListAlarmRules','mse')
 		self.set_method('GET')
 
 		if hasattr(self, "endpoint_map"):
@@ -51,3 +51,8 @@ class ListAlarmRulesRequest(RpcRequest):
 
 	def set_PageSize(self, PageSize):  # Integer
 		self.add_query_param('PageSize', PageSize)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
