@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class ListClusterVersionsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListClusterVersions')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListClusterVersions','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -36,3 +36,8 @@ class ListClusterVersionsRequest(RpcRequest):
 
 	def set_ClusterType(self, ClusterType):  # String
 		self.add_query_param('ClusterType', ClusterType)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
