@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class ListListenersByConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListListenersByConfig')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListListenersByConfig','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -51,6 +51,11 @@ class ListListenersByConfigRequest(RpcRequest):
 
 	def set_RequestPars(self, RequestPars):  # String
 		self.add_query_param('RequestPars', RequestPars)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
 	def get_Group(self): # String
 		return self.get_query_params().get('Group')
 
