@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class ListNacosHistoryConfigsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListNacosHistoryConfigs')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListNacosHistoryConfigs','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -61,6 +61,11 @@ class ListNacosHistoryConfigsRequest(RpcRequest):
 
 	def set_PageSize(self, PageSize):  # Integer
 		self.add_query_param('PageSize', PageSize)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
 	def get_Group(self): # String
 		return self.get_query_params().get('Group')
 
