@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class QueryMonitorRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'QueryMonitor')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'QueryMonitor','mse')
 		self.set_method('GET')
 
 		if hasattr(self, "endpoint_map"):
@@ -56,6 +56,11 @@ class QueryMonitorRequest(RpcRequest):
 
 	def set_RequestPars(self, RequestPars):  # String
 		self.add_query_param('RequestPars', RequestPars)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
 	def get_Step(self): # Long
 		return self.get_query_params().get('Step')
 
