@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class UpdateNacosConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'UpdateNacosConfig')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'UpdateNacosConfig','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -81,6 +81,11 @@ class UpdateNacosConfigRequest(RpcRequest):
 
 	def set_DataId(self, DataId):  # String
 		self.add_query_param('DataId', DataId)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
 	def get_Desc(self): # String
 		return self.get_query_params().get('Desc')
 
