@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class UpdateNacosInstanceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'UpdateNacosInstance')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'UpdateNacosInstance','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -41,16 +41,31 @@ class UpdateNacosInstanceRequest(RpcRequest):
 
 	def set_ClusterName(self, ClusterName):  # String
 		self.add_query_param('ClusterName', ClusterName)
-	def get_Ip(self): # String
-		return self.get_query_params().get('Ip')
-
-	def set_Ip(self, Ip):  # String
-		self.add_query_param('Ip', Ip)
 	def get_Ephemeral(self): # Boolean
 		return self.get_query_params().get('Ephemeral')
 
 	def set_Ephemeral(self, Ephemeral):  # Boolean
 		self.add_query_param('Ephemeral', Ephemeral)
+	def get_Enabled(self): # Boolean
+		return self.get_query_params().get('Enabled')
+
+	def set_Enabled(self, Enabled):  # Boolean
+		self.add_query_param('Enabled', Enabled)
+	def get_NamespaceId(self): # String
+		return self.get_query_params().get('NamespaceId')
+
+	def set_NamespaceId(self, NamespaceId):  # String
+		self.add_query_param('NamespaceId', NamespaceId)
+	def get_ServiceName(self): # String
+		return self.get_query_params().get('ServiceName')
+
+	def set_ServiceName(self, ServiceName):  # String
+		self.add_query_param('ServiceName', ServiceName)
+	def get_Ip(self): # String
+		return self.get_query_params().get('Ip')
+
+	def set_Ip(self, Ip):  # String
+		self.add_query_param('Ip', Ip)
 	def get_Weight(self): # String
 		return self.get_query_params().get('Weight')
 
@@ -61,28 +76,18 @@ class UpdateNacosInstanceRequest(RpcRequest):
 
 	def set_GroupName(self, GroupName):  # String
 		self.add_query_param('GroupName', GroupName)
-	def get_Enabled(self): # Boolean
-		return self.get_query_params().get('Enabled')
-
-	def set_Enabled(self, Enabled):  # Boolean
-		self.add_query_param('Enabled', Enabled)
 	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
 	def set_InstanceId(self, InstanceId):  # String
 		self.add_query_param('InstanceId', InstanceId)
-	def get_NamespaceId(self): # String
-		return self.get_query_params().get('NamespaceId')
-
-	def set_NamespaceId(self, NamespaceId):  # String
-		self.add_query_param('NamespaceId', NamespaceId)
 	def get_Port(self): # Integer
 		return self.get_query_params().get('Port')
 
 	def set_Port(self, Port):  # Integer
 		self.add_query_param('Port', Port)
-	def get_ServiceName(self): # String
-		return self.get_query_params().get('ServiceName')
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
 
-	def set_ServiceName(self, ServiceName):  # String
-		self.add_query_param('ServiceName', ServiceName)
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
